@@ -8,10 +8,10 @@ import os
 class Version(tuple):
     """Represent the version of a dependency as a tuple"""
 
-    def __new__(cls, *args):
-        # Support tuple or varargs instantiation
-        value = args[0] if len(args) == 1 else args
-        return tuple.__new__(Version, value)
+    def __new__(cls, name, *args):
+        inst = tuple.__new__(Version, args)
+        inst.name = name
+        return inst
 
     def human_version(self):
         return ".".join(map(str, self))
@@ -19,22 +19,37 @@ class Version(tuple):
     def __str__(self):
         return self.human_version()
 
+    def check(self, version_tuple):
+        """Raises ImportError if the version isn't supported"""
+
+        if self[0] == version_tuple[0] and version_tuple >= self:
+            return
+        raise ImportError("%s %s required. %s found." % (
+            self.name, self, Version("", *version_tuple)))
+
 
 class MinVersions(object):
     """Dependency requirements for Quod Libet / Ex Falso"""
-    PYTHON = Version(2, 7)
-    MUTAGEN = Version(1, 27)
 
-VERSION_TUPLE = Version(3, 5, 1)
+    PYTHON2 = Version("Python2", 2, 7)
+    PYTHON3 = Version("Python3", 3, 4)
+    MUTAGEN = Version("Mutagen", 1, 30)
+    GTK = Version("GTK+", 3, 10)
+    PYGOBJECT = Version("PyGObject", 3, 10)
+    GSTREAMER = Version("GStreamer", 1, 0)
+
+
+VERSION_TUPLE = Version("", 3, 6, 1)
 VERSION = str(VERSION_TUPLE)
 
 # entry point for the user guide / wiki
-BRANCH_NAME = "quodlibet-3.5"
+BRANCH_NAME = "quodlibet-3.6"
 DOCS_BASE_URL = "https://quodlibet.readthedocs.org/en/%s"
 DOCS_LATEST = DOCS_BASE_URL % "latest"
 DOCS_BASE_URL %= BRANCH_NAME if BRANCH_NAME != "master" else "latest"
 ONLINE_HELP = DOCS_BASE_URL + "/guide/index.html"
 SEARCH_HELP = DOCS_BASE_URL + "/guide/searching.html"
+SHORTCUTS_HELP = DOCS_BASE_URL + "/guide/shortcuts.html"
 
 # Email used as default for reading/saving per-user data in tags, etc.
 EMAIL = os.environ.get("EMAIL", "quodlibet@lists.sacredchao.net")
@@ -52,7 +67,7 @@ Nick Boultbee""".split("\n")
 
 # about dialog, --version etc.
 WEBSITE = "https://quodlibet.readthedocs.org/"
-COPYRIGHT = """Copyright © 2004-2015 %s...""" % ", ".join(MAIN_AUTHORS)
+COPYRIGHT = """Copyright © 2004-2016 %s...""" % ", ".join(MAIN_AUTHORS)
 
 AUTHORS = sorted("""\
 Alexandre Passos
@@ -60,6 +75,7 @@ Alexey Bobyakov
 Alex Geoffrey Smith
 Anders Carlsson
 Andreas Bombe
+Andrew Chadwick
 Anton Shestakov
 Ari Pollak
 Aymeric Mansoux
